@@ -1,6 +1,6 @@
 /* ex: set ts=4: */
 /***************************************************************************
- *  gst-misc-0.10.c
+ *  gst-misc.c
  *
  *  Copyright (C) 2005 Novell
  *  Written by Aaron Bockover (aaron@aaronbock.net)
@@ -37,16 +37,17 @@
 #include <string.h>
 
 #include <gst/gst.h>
+#include <gst/gconf/gconf.h>
 
 static gboolean gstreamer_initialized = FALSE;
 
 void gstreamer_initialize()
 {
-    if(gstreamer_initialized) {
+    if(gstreamer_initialized)
         return;
-    }
 
     gst_init(NULL, NULL);
+
     gstreamer_initialized = TRUE;
 }
 
@@ -61,60 +62,81 @@ gstreamer_test_encoder(gchar *encoder_pipeline)
     element = gst_parse_launch(pipeline, &error);
     g_free(pipeline);
     
-    if(element != NULL) {
+    if(element != NULL)
         gst_object_unref(GST_OBJECT(element));
-    }
     
     return error == NULL;
+    
+    /*GstElement *element = NULL;
+    gchar *pipeline;
+    
+    pipeline = g_strdup_printf("audioconvert ! %s", encoder_pipeline);
+    element = gst_gconf_render_bin_from_description(pipeline);
+    g_free(pipeline);
+    
+    if(element) {
+        gst_object_unref(GST_OBJECT(element));
+        return TRUE;
+    }
+    
+    return FALSE;*/
 }
 
 static void
-gst_typefind_type_found_callback(GstElement *typefind, guint probability, 
-    GstCaps *caps, gchar **type)
+gst_type_found_cb(GstElement *typefind, guint probability, GstCaps *caps, 
+    gchar **type)
 {
     *type = gst_caps_to_string(caps);    
 }
 
+static void
+gst_error_cb(GstElement *pipeline, GstElement *source, GError *error,
+    gchar *debug, gchar **data)
+{
+    *data = "error";
+}
+
 gchar *
 gstreamer_detect_mimetype(const gchar *uri)
 {
-    return NULL;
-    /*GstElement *pipeline;
+    GstElement *pipeline;
     GstElement *source;
     GstElement *typefind;
-    GstElement *fakesink;
     gchar *mimetype = NULL;
 
     pipeline = gst_pipeline_new("new");
-        
+    g_signal_connect(pipeline, "error", G_CALLBACK(gst_error_cb), &mimetype);
+
     source = gst_element_factory_make("gnomevfssrc", "source");
     typefind = gst_element_factory_make("typefind", "typefind");
-    fakesink = gst_element_factory_make("fakesink", "fakesink");
 
     if(source == NULL || typefind == NULL) {
-        gst_object_unref(pipeline);
+        gst_object_unref(GST_OBJECT(pipeline));
         return NULL;
     }
 
-    g_object_set(source, "location", uri, NULL);
-    g_signal_connect(typefind, "have-type", 
-        G_CALLBACK(gst_typefind_type_found_callback), &mimetype);
+    g_object_set(G_OBJECT(source), "location", uri, NULL);
+    g_signal_connect(typefind, "have-type", G_CALLBACK(gst_type_found_cb), 
+        &mimetype);
 
-    gst_bin_add_many(GST_BIN(pipeline), source, typefind, fakesink, NULL);
+    gst_bin_add_many(GST_BIN(pipeline), source, typefind, NULL);
     gst_element_link(source, typefind);
-    gst_element_link(typefind, fakesink);
-    
-    if(gst_element_set_state(pipeline, GST_STATE_PLAYING) == GST_STATE_CHANGE_ASYNC) {
-        if (gst_element_get_state(pipeline, NULL, NULL, -1) == GST_STATE_CHANGE_FAILURE) {
-            gst_object_unref(pipeline);
-            return NULL;
+    gst_element_set_state(GST_ELEMENT(pipeline), GST_STATE_PLAYING);
+
+    do {
+        if(!gst_bin_iterate(GST_BIN(pipeline))) {
+            break;
         }
+    } while(mimetype == NULL);
+
+    if(strcmp(mimetype, "error") == 0) {
+        mimetype = NULL;
     }
 
-    while((mimetype == NULL) && (pipeline->current_state == GST_STATE_PLAYING));
-    
-    gst_element_set_state(pipeline, GST_STATE_NULL);
-    gst_object_unref(pipeline);
-        
-    return mimetype;*/
+    gst_element_set_state(GST_ELEMENT(pipeline), GST_STATE_NULL);
+    gst_object_unref(GST_OBJECT(pipeline));
+
+    return mimetype;
 }
+
+
