@@ -1,4 +1,4 @@
-/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
+
 /***************************************************************************
  *  PlaylistView.cs
  *
@@ -146,6 +146,8 @@ namespace Banshee
             SetPosition(WindowPosition.Center);
             TypeHint = Gdk.WindowTypeHint.Utility;
             Resizable = false;
+            
+            IconThemeUtils.SetWindowIcon(this);
         
             VBox vbox = new VBox();
             vbox.Spacing = 10;
